@@ -1,4 +1,4 @@
-/* $OpenBSD: req.c,v 1.3 2014/10/01 13:15:40 sthen Exp $ */
+/* $OpenBSD: req.c,v 1.4 2014/10/16 10:43:54 jsing Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -379,7 +379,7 @@ bad:
 		BIO_printf(bio_err, " -newkey rsa:bits generate a new RSA key of 'bits' in size\n");
 		BIO_printf(bio_err, " -newkey dsa:file generate a new DSA key, parameters taken from CA in 'file'\n");
 		BIO_printf(bio_err, " -newkey ec:file generate a new EC key, parameters taken from CA in 'file'\n");
-		BIO_printf(bio_err, " -[digest]      Digest to sign with (md5, sha1, md2, mdc2, md4)\n");
+		BIO_printf(bio_err, " -[digest]      Digest to sign with (md5, sha1, md4)\n");
 		BIO_printf(bio_err, " -config file   request template file.\n");
 		BIO_printf(bio_err, " -subj arg      set or modify request subject\n");
 		BIO_printf(bio_err, " -multivalue-rdn enable support for multivalued RDNs\n");
