@@ -1,4 +1,4 @@
-/* $OpenBSD: c_all.c,v 1.15 2015/02/07 03:23:05 jsing Exp $ */
+/* $OpenBSD: c_all.c,v 1.16 2015/02/10 11:45:09 jsing Exp $ */
 /* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
  * All rights reserved.
  *
@@ -265,9 +265,6 @@ OpenSSL_add_all_digests(void)
 	EVP_add_digest(EVP_streebog256());
 	EVP_add_digest(EVP_streebog512());
 #endif
-#if !defined(OPENSSL_NO_MDC2) && !defined(OPENSSL_NO_DES)
-	EVP_add_digest(EVP_mdc2());
-#endif
 #ifndef OPENSSL_NO_RIPEMD
 	EVP_add_digest(EVP_ripemd160());
 	EVP_add_digest_alias(SN_ripemd160, "ripemd");
